
**Understand** the structure of your RDF data at a glance using automatically built **application profiles** and spot differences between dataset structures. 

An [_application profile_](https://en.wikipedia.org/wiki/Application_profile), in this context, is the set of [_data shapes_](https://www.w3.org/2014/data-shapes/wiki/Main_Page) designed for a particular purpose acting as constraints on how the data are instantiated and so can be used to validate the data.

_Fingerprinting_ is the action of generating, or rather, guessing, the application profile applied to a particular dataset. This is an inductive process of reconstructing the data shape for each class instantiated in the dataset. 

![test](https://github.com/meaningfy-ws/rdf-fingerprinter/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/meaningfy-ws/rdf-fingerprinter/branch/master/graph/badge.svg)](https://codecov.io/gh/meaningfy-ws/eds4jinja2)
[![Documentation Status](https://readthedocs.org/projects/rdf-fingerprinter/badge/?version=latest)](https://eds4jinja2.readthedocs.io/en/latest/?badge=latest)

![PyPI](https://img.shields.io/pypi/v/rdf-fingerprinter?color=teal&label=version)
![PyPI - Status](https://img.shields.io/pypi/status/rdf-fingerprinter)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rdf-fingerprinter)
![PyPI - License](https://img.shields.io/pypi/l/rdf-fingerprinter?color=green)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/rdf-fingerprinter)

# Installation
RDF fingerprinter may be installed with pip as follows. 
 
```
pip install rdf-fingerprinter
```
Nore that Python version 3.7 or later is required.  

# Getting started



# Licence 
_RDF Fingerprinter_ is freely distributable under the terms of the [GNU GPLv3](https://www.gnu.org/licenses/gpl-3.0.en.html)